@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rdf.c,v 1.48 2007/04/14 15:45:28 hany Exp $
+ * $Id: rdf.c,v 1.49 2007/08/28 22:44:22 hany Exp $
  */
 
 #include "config.h"
@@ -759,7 +759,24 @@ void dumpResRdf(rpmRessPtr res) {
 
     if (res->nb_provider == 0) return;
 
-    snprintf(file, sizeof(file), "%s/%s.rdf", base, res->name);
+    if (res->name[0] != '/')
+        snprintf(file, sizeof(file), "%s/%s.rdf", base, res->name);
+    else {
+        // replace all '/' with '_' to avoid "couldn't open <base>//usr/bin/mailq.rdf for writing !"
+
+        snprintf(buf, sizeof(buf), "%s", res->name);
+        // we reuse 'buffer' as cursor here
+        buffer = &buf[0];
+        while (*buffer != '\0') {
+            if (*buffer == '/')
+                *buffer = '_';
+            buffer++;
+        }
+        snprintf(file, sizeof(file), "%s/%s.rdf", base, buf);
+
+        if (rpm2htmlVerbose > 1)
+            fprintf(stdout, "warning: '/' in resource name converted into '_': %s\n", buf);
+    }
 
     /*
      * Create the directory if needed
