@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.119 2008/11/13 23:59:59 hany Exp $
+ * $Id: rpmopen.c,v 1.120 2009/04/28 20:29:17 hany Exp $
  */
 
 #include <config.h>
@@ -70,20 +70,25 @@ typedef struct headerTagTableEntry *headerTagTableEntryPtr;
 /*
  * Get the internal number associated with an RPM tag.
  */
-static int
-getTagNumber(char *tag)
-{
-    int i;
-    headerTagTableEntryPtr t;
-
-    t = (headerTagTableEntryPtr) rpmTagTable;
-    for (i = 0; i < rpmTagTableSize; i++, t++) {
-        if (!strcasecmp(tag, t->name))
-            return (t->val);
-    }
-    fprintf(stderr, "getTagNumber(%s) : unknown tag !\n", tag);
-    return (-1);
-}
+// removal of this possibly breaks compatibility with some ancient RPM but while
+// some tags are alredy used as macros directly, without 'getTagNumber()', removal
+// of this methond hopefully wont make in worser BUT it will help us compile this
+// against rpm.org's rpm-4.6
+// XXX TODO: clean-up
+//static int
+//getTagNumber(char *tag)
+//{
+//    int i;
+//    headerTagTableEntryPtr t;
+//
+//    t = (headerTagTableEntryPtr) rpmTagTable;
+//    for (i = 0; i < rpmTagTableSize; i++, t++) {
+//        if (!strcasecmp(tag, t->name))
+//            return (t->val);
+//    }
+//    fprintf(stderr, "getTagNumber(%s) : unknown tag !\n", tag);
+//    return (-1);
+//}
 
 /*
  * Free up the extra data not needed for the last stage processing.
@@ -647,7 +652,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
         rpm->extra->packager = xmlStrdup(protectEmail((char *) p));
     }
     ENTRY_CLEANUP(p);
-    if (!headerGetEntry(h, RPMTAG_COPYRIGHT, &type, &p, &count) || !p ||
+    if (!headerGetEntry(h, RPMTAG_LICENSE, &type, &p, &count) || !p ||
         (type != RPM_STRING_TYPE)) {
         rpm->extra->copyright = NULL;
     } else {
@@ -783,7 +788,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
     rpm->filename = xmlStrdup(nameRpm);
 
     /* package-xxx.rpm provides at least the resource "package" */
-    val = getTagNumber("RPMTAG_PROVIDES");
+    val = RPMTAG_PROVIDES;
     if (!headerGetEntry(h, val, &type, &p, &count) || !p) {
         rpm->extra->nb_resources = 1;
         rpm->extra->max_resources = 1;
@@ -819,7 +824,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
     }
     ENTRY_CLEANUP(p);
 
-    val = getTagNumber("RPMTAG_REQUIRENAME");
+    val = RPMTAG_REQUIRENAME;
     if (!headerGetEntry(h, val, &type, &p, &count) || !p) {
         rpm->extra->nb_requires = 0;
         rpm->extra->requires = NULL;
@@ -841,8 +846,8 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
             fprintf(stderr, ": ran out of memory\n");
             exit(1);
         }
-        valv = getTagNumber("RPMTAG_REQUIREVERSION");
-        valf = getTagNumber("RPMTAG_REQUIREFLAGS");
+        valv = RPMTAG_REQUIREVERSION;
+        valf = RPMTAG_REQUIREFLAGS;
         headerGetEntry(h, valv, &type2, &q, &count2);
         headerGetEntry(h, valf, &type3, &r, &count3);
 
@@ -900,7 +905,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
             fname = rpmfiFN(fi);
 #else
   #if defined(RPMTAG_FILENAMES)
-    val = getTagNumber("RPMTAG_FILENAMES");
+    val = RPMTAG_FILENAMES;
     headerGetEntry(h, val, &type, &p, &count);
   #else
     rpmBuildFileList(h, (const char ***) &p, &count);
@@ -1042,7 +1047,9 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
     int rc;
     Header h = NULL;
     Header s = NULL;
-    struct rpmlead lead;
+    // XXX phanecak: readLead() in not available with rpm.org's rpm-4.6 and for now I have
+    // no idea what to do with that so for now I just skip it
+    //struct rpmlead lead;
     int isSource;
     char buffer[500];
     struct stat buf;
@@ -1091,7 +1098,7 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
             if (!h) {
                 fprintf(stderr,
                         "old format source packages cannot be queried\n");
-                fdClose(fd);
+                Fclose(fd);
                 return (NULL);
             }
 	    isSource = (headerIsEntry(h, RPMTAG_SOURCEPACKAGE) ? 1 : 0);
@@ -1099,18 +1106,18 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
         case 1:
             fprintf(stderr, "%s does not appear to be a RPM package\n",
                     nameRpm);
-            fdClose(fd);
+            Fclose(fd);
             return (NULL);
         case 2:
             fprintf(stderr, "query of %s failed\n", nameRpm);
-            fdClose(fd);
+            Fclose(fd);
             return (NULL);
         case 4:
 	    fprintf(stderr, "%s: Error %d Found and Ignored\n", nameRpm, rc);
 	    if (!h) {
 		fprintf(stderr,
 			"packages cannot be queried\n");
-		fdClose(fd);
+		Fclose(fd);
 		return (NULL);
 	    }
 	    isSource = (headerIsEntry(h, RPMTAG_SOURCEPACKAGE) ? 1 : 0);
@@ -1118,7 +1125,7 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
         default:
             fprintf(stderr, "rpmReadPackageHeader(%s): unknown error %d\n",
                     nameRpm, rc);
-            fdClose(fd);
+            Fclose(fd);
             return (NULL);
     }
 
@@ -1135,66 +1142,68 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
     }
 
     /* read the RPM signature */
-    if (readLead(fd, &lead)) {
-        fprintf(stderr, "readLead failed\n");
-        fdClose(fd);
-        return (NULL);
-    }
-    switch (lead.major) {
-        case 1:
-            fprintf(stderr, "no signature available (v1.0 RPM) in %s\n",
-                    nameRpm);
-            break;
-        default:
-#ifdef HAVE_RPM42
-            if (rpmReadSignature(fd, &s, lead.signature_type, NULL)) {
-#else
-            if (rpmReadSignature(fd, &s, lead.signature_type)) {
-#endif
-                fprintf(stderr, "rpmReadSignature failed\n");
-                fdClose(fd);
-                return (NULL);
-            }
-            if (!s) {
-                fprintf(stderr, "no signature available in %s\n", nameRpm);
-                fdClose(fd);
-                return (NULL);
-            }
-#if defined(WITH_GPG)
-            /* open temp file for writing */
-            sigtarget = xmlMalloc(30);
-            strcpy(sigtarget, "/tmp/rpm2html.date.XXXXXX");
-            sigtarget = mktemp(sigtarget);
-            ofd = Fopen(sigtarget, "w.ufdio");
-            if (ofd == NULL || Ferror(ofd)) {
-                fprintf(stderr, "Fopen of %s failed: %s\n", sigtarget,
-                        Fstrerror(ofd));
-                xmlFree(sigtarget);
-                sigtarget = NULL;
-            }
-
-            /* write the header and archive to a temp file */
-            while ((count =
-                    Fread(stbuffer, sizeof(stbuffer[0]), sizeof(stbuffer),
-                          fd)) > 0) {
-                if (Fwrite(stbuffer, sizeof(stbuffer[0]), count, ofd) < 0) {
-                    fprintf(stderr, "%s: Fwrite failed: %s\n", sigtarget,
-                            Fstrerror(ofd));
-                    xmlFree(sigtarget);
-                    sigtarget = NULL;
-                }
-            }
-            if (count < 0) {
-                fprintf(stderr, "%s: Fread failed: %s\n", buffer,
-                        Fstrerror(fd));
-                xmlFree(sigtarget);
-                sigtarget = NULL;
-            }
-
-            Fclose(ofd);
-#endif
-            break;
-    }
+    // XXX phanecak: readLead() in not available with rpm.org's rpm-4.6 and for now I have
+    // no idea what to do with that so for now I just skip it
+//    if (readLead(fd, &lead)) {
+//        fprintf(stderr, "readLead failed\n");
+//        fdClose(fd);
+//        return (NULL);
+//    }
+//    switch (lead.major) {
+//        case 1:
+//            fprintf(stderr, "no signature available (v1.0 RPM) in %s\n",
+//                    nameRpm);
+//            break;
+//        default:
+//#ifdef HAVE_RPM42
+//            if (rpmReadSignature(fd, &s, lead.signature_type, NULL)) {
+//#else
+//            if (rpmReadSignature(fd, &s, lead.signature_type)) {
+//#endif
+//                fprintf(stderr, "rpmReadSignature failed\n");
+//                fdClose(fd);
+//                return (NULL);
+//            }
+//            if (!s) {
+//                fprintf(stderr, "no signature available in %s\n", nameRpm);
+//                fdClose(fd);
+//                return (NULL);
+//            }
+//#if defined(WITH_GPG)
+//            /* open temp file for writing */
+//            sigtarget = xmlMalloc(30);
+//            strcpy(sigtarget, "/tmp/rpm2html.date.XXXXXX");
+//            sigtarget = mktemp(sigtarget);
+//            ofd = Fopen(sigtarget, "w.ufdio");
+//            if (ofd == NULL || Ferror(ofd)) {
+//                fprintf(stderr, "Fopen of %s failed: %s\n", sigtarget,
+//                        Fstrerror(ofd));
+//                xmlFree(sigtarget);
+//                sigtarget = NULL;
+//            }
+//
+//            /* write the header and archive to a temp file */
+//            while ((count =
+//                    Fread(stbuffer, sizeof(stbuffer[0]), sizeof(stbuffer),
+//                          fd)) > 0) {
+//                if (Fwrite(stbuffer, sizeof(stbuffer[0]), count, ofd) < 0) {
+//                    fprintf(stderr, "%s: Fwrite failed: %s\n", sigtarget,
+//                            Fstrerror(ofd));
+//                    xmlFree(sigtarget);
+//                    sigtarget = NULL;
+//                }
+//            }
+//            if (count < 0) {
+//                fprintf(stderr, "%s: Fread failed: %s\n", buffer,
+//                        Fstrerror(fd));
+//                xmlFree(sigtarget);
+//                sigtarget = NULL;
+//            }
+//
+//            Fclose(ofd);
+//#endif
+//            break;
+//    }
 
     /* close the descriptor */
     Fclose(fd);
